extract.spdur<-function(model, beside = FALSE, include.duration = TRUE, include.risk = TRUE, 
    include.aic = TRUE, include.loglik = TRUE, include.nobs = TRUE, 
    include.bic=TRUE, include.dist = TRUE,...) 
{
    s <- summary(model, ...)
    dist <- model$distr
    gof <- numeric()
    gof.names <- character()
    gof.decimal <- logical()
    if (include.nobs == TRUE) {
        n <- model$obs
        gof <- c(gof, n)
        gof.names <- c(gof.names, "Num. obs.")
        gof.decimal <- c(gof.decimal, FALSE)
    }
    if (include.loglik == TRUE) {
        lik <- logLik(model)[1]
        gof <- c(gof, lik)
        gof.names <- c(gof.names, "Log Likelihood")
        gof.decimal <- c(gof.decimal, TRUE)
    }
    if (include.aic == TRUE) {
        aic <- AIC(model)
        gof <- c(gof, aic)
        gof.names <- c(gof.names, "AIC")
        gof.decimal <- c(gof.decimal, TRUE)
    }
    if (include.bic == TRUE) {
        bic <- BIC(model)
        gof <- c(gof, bic)
        gof.names <- c(gof.names, "BIC")
        gof.decimal <- c(gof.decimal, TRUE)
    }
    duration <- s$duration
    alpha <- s$alpha
    risk <- s$split
    if (beside == FALSE) {
        if (include.duration == TRUE && include.risk == TRUE) {
            names(duration) <- paste("Duration model:", rownames(duration))
            names(risk) <- paste("Risk model:", rownames(risk))
            coef.block <- rbind(duration, alpha,risk)
        }
        else if (include.duration == TRUE) {
            coef.block <- rbind(duration, alpha)
        }
        else if (include.risk == TRUE) {
            coef.block <- risk
        }
        else {
            stop(paste("Either the include.duration or the include.risk argument", 
                "must be TRUE."))
        }
        names <- rownames(coef.block)
        co <- coef.block[, 1]
        se <- coef.block[, 2]
        pval <- coef.block[, 4]
        tr <- createTexreg(coef.names = names, coef = co, se = se, 
            pvalues = pval, gof.names = gof.names, gof = gof, 
            gof.decimal = gof.decimal)
        return(tr)
    }
    else {
        trList <- list()
        d.names <- c(names(duration), "log(alpha)")
        d.co <- c(duration[, 1], alpha[, 1])
        d.se <- c(duration[, 2], alpha[, 2])
        d.pval <- c(duration[, 4],alpha[, 4])
        r.names <- rownames(risk)
        r.co <- risk[, 1]
        r.se <- risk[, 2]
        r.pval <- risk[, 4]
        if (include.duration == TRUE) {
            tr <- createTexreg(coef.names = d.names, coef = d.co, 
                se = d.se, pvalues = d.pval, gof.names = gof.names, 
                gof = gof, gof.decimal = gof.decimal, 
                model.name = paste("Duration model (", dist,")", sep=""))
            trList[[length(trList) + 1]] <- tr
        }
        if (include.risk == TRUE) {
            tr <- createTexreg(coef.names = r.names, coef = r.co, 
                se = r.se, pvalues = r.pval, gof.names = gof.names, 
                gof = gof, gof.decimal = gof.decimal, model.name = "Risk model")
            trList[[length(trList) + 1]] <- tr
        }
        if (length(trList) == 0) {
            stop(paste("Either the include.duration or the include.risk argument", 
                "must be TRUE."))
        }
        return(trList)
    }
}

setMethod("extract", signature = className("spdur", "spduration"),
    definition = extract.spdur)